@@ -6,4 +6,4 @@ def precondition(statement):
     Raise TestSkipped if statement is false
     """
     if not statement:
-        raise TestSkipped('Skipping test because precondition is not met')
+        raise TestSkipped("Skipping test because precondition is not met")
