@@ -11,6 +11,6 @@ def path_to_entry_script():
     stack = traceback.extract_stack()
     if stack:
         fn = stack[0].filename
-        if not fn.startswith('<'):
+        if not fn.startswith("<"):
             return os.path.join(os.getcwd(), fn)
     return None
