@@ -8,4 +8,4 @@ def structures_from_json(json_string):
 
 
 def structures_to_json(sequence_of_structures):
-    return '[' + ','.join([s.to_json() for s in sequence_of_structures]) + ']'
+    return "[" + ",".join([s.to_json() for s in sequence_of_structures]) + "]"
